@@ -42,13 +42,16 @@ def write_default_ansible_cfg(work_dir,
                os.path.join(work_dir, 'ansible.log'))
     config.set('defaults', 'forks', '25')
     config.set('defaults', 'timeout', '30')
+    config.set('defaults', 'gather_timeout', '30')
 
     # mistral user has no home dir set, so no place to save a known hosts file
     config.set('ssh_connection', 'ssh_args',
                '-o UserKnownHostsFile=/dev/null '
                '-o StrictHostKeyChecking=no '
                '-o ControlMaster=auto '
-               '-o ControlPersist=30m')
+               '-o ControlPersist=30m '
+               '-o ServerAliveInterval=5 '
+               '-o ServerAliveCountMax=5')
     config.set('ssh_connection', 'control_path_dir',
                os.path.join(work_dir, 'ansible-ssh'))
     config.set('ssh_connection', 'retries', '8')
@@ -68,7 +71,7 @@ class AnsibleAction(actions.Action):
         self.hosts = self._kwargs_for_run.pop('hosts', None)
         self.module = self._kwargs_for_run.pop('module', None)
         self.module_args = self._kwargs_for_run.pop('module_args', None)
-        if self.module_args:
+        if self.module_args and isinstance(self.module_args, dict):
             self.module_args = json.dumps(self.module_args)
         self.limit_hosts = self._kwargs_for_run.pop('limit_hosts', None)
         self.remote_user = self._kwargs_for_run.pop('remote_user', None)
