@@ -27,10 +27,10 @@ from tripleo_common.image import image_uploader
 
 
 CONTAINER_IMAGES_DEFAULTS = {
-    'namespace': 'docker.io/tripleomaster',
+    'namespace': 'docker.io/tripleoqueens',
     'ceph_namespace': 'docker.io/ceph',
     'ceph_image': 'daemon',
-    'ceph_tag': 'v3.0.3-stable-3.0-luminous-centos-7-x86_64',
+    'ceph_tag': 'v3.2.1-stable-3.2-luminous-centos-7-x86_64',
     'name_prefix': 'centos-binary-',
     'name_suffix': '',
     'tag': 'current-tripleo',
