@@ -125,8 +125,12 @@ class PrepareLogDownloadActionTest(base.TestCase):
 
         self.ctx = mock.MagicMock()
 
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_service')
     @mock.patch('tripleo_common.utils.tarball.create_tarball')
-    def test_run_success(self, mock_create_tarball):
+    def test_run_success(self,
+                         mock_create_tarball,
+                         mock_get_obj_service):
+
         get_object_mock_calls = [
             mock.call('logging-container', lf) for lf in self.log_files
         ]
@@ -134,6 +138,12 @@ class PrepareLogDownloadActionTest(base.TestCase):
             mock.call('logging-container')
         ]
 
+        swift_service = mock.MagicMock()
+        swift_service.delete.return_value = ([
+            {'success': True},
+        ])
+        mock_get_obj_service.return_value = swift_service
+
         action = logging_to_swift.PrepareLogDownloadAction(
             'logging-container', 'downloads-container', 3600
         )
@@ -145,10 +155,20 @@ class PrepareLogDownloadActionTest(base.TestCase):
             get_object_mock_calls, any_order=True)
         mock_create_tarball.assert_called_once()
 
+    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_service')
     @mock.patch('tripleo_common.utils.tarball.create_tarball')
-    def test_run_error_creating_tarball(self, mock_create_tarball):
+    def test_run_error_creating_tarball(self,
+                                        mock_create_tarball,
+                                        mock_get_obj_service):
+
         mock_create_tarball.side_effect = processutils.ProcessExecutionError
 
+        swift_service = mock.MagicMock()
+        swift_service.delete.return_value = ([
+            {'success': True},
+        ])
+        mock_get_obj_service.return_value = swift_service
+
         action = logging_to_swift.PrepareLogDownloadAction(
             'logging-container', 'downloads-container', 3600
         )
